@@ -334,7 +334,7 @@ createBoxTools <- function(collapsible, collapsed, closable,
       class = btnClass, 
       `data-widget` = "remove", 
       type = "button",
-      shiny::icon("times")
+      shiny::icon("xmark")
     )
   } 
   
@@ -444,4 +444,4 @@ waiterShowOnLoad <- function(
   
   shiny::HTML(sprintf("<script>%s</script>", show))
   
-}
\ No newline at end of file
+}
