@@ -1,33 +1,33 @@
 accordion <- 'box(
   title = "Accordion Demo",
-  width = NULL,
+  width = 12,
   accordion(
-    inputId = "accordion1",
+    id = "accordion1",
     accordionItem(
       title = "Accordion 1 Item 1",
-      color = "success",
+      status = "success",
       collapsed = TRUE,
       "This is some text!"
     ),
     accordionItem(
       title = "Accordion 1 Item 2",
-      color = "success",
+      status = "success",
       collapsed = FALSE,
       "This is some text!"
     )
   ),
   br(),
   accordion(
-    inputId = "accordion2",
+    id = "accordion2",
     accordionItem(
       title = "Accordion 2 Item 1",
-      color = "danger",
+      status = "danger",
       collapsed = FALSE,
       "This is some text!"
     ),
     accordionItem(
       title = "Accordion 2 Item 2",
-      color = "danger",
+      status = "danger",
       collapsed = TRUE,
       "This is some text!"
     )
